@@ -22,13 +22,27 @@
 # SOFTWARE.
 
 import time
-from datetime import datetime, timedelta
+from datetime import datetime, timedelta, tzinfo
 from contextlib import contextmanager
 from . import base
 
 import os
 
 
+# just use datetime.timezone.utc instead when we drop Python 2.7
+class UTC(tzinfo):
+    def utcoffset(self, dt):
+        return timedelta(0)
+
+    def tzname(self, dt):
+        return "UTC"
+
+    dst = utcoffset
+
+
+utc = UTC()
+
+
 @contextmanager
 def tz(the_tz):
     orig = os.environ.get('TZ')
@@ -66,7 +80,8 @@ class Clock(base.InLoopPollText):
     # theoreticaly call our method too early and we could get something
     # like (x-1).999 instead of x.000
     def _get_time(self):
-        return (datetime.now() + self.DELTA).strftime(self.format)
+        now = datetime.now(utc).astimezone()
+        return (now + self.DELTA).strftime(self.format)
 
     def poll(self):
         # We use None as a sentinel here because C's strftime defaults to UTC
